@@ -1314,7 +1314,7 @@ Options -Indexes
     
     // Helper methods
     
-    private function getSite($siteId) {
+    public function getSite($siteId) {
         $stmt = $this->db->prepare("SELECT * FROM wordpress_sites WHERE id = ?");
         $stmt->execute([$siteId]);
         return $stmt->fetch(PDO::FETCH_ASSOC);
