@@ -180,6 +180,41 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                     $message_type = 'danger';
                 }
                 break;
+            case 'sync_blocked_ips':
+                try {
+                    $sync_results = $LogMonitor->sync_blocked_ips();
+                    
+                    if ($sync_results['success']) {
+                        if ($sync_results['synced_count'] > 0) {
+                            $message = 'Successfully synced ' . $sync_results['synced_count'] . ' IP(s) across all services.';
+                            if (!empty($sync_results['errors'])) {
+                                $message .= ' Some warnings occurred: ' . implode(', ', array_slice($sync_results['errors'], 0, 3));
+                                if (count($sync_results['errors']) > 3) {
+                                    $message .= ' (and ' . (count($sync_results['errors']) - 3) . ' more)';
+                                }
+                                $message_type = 'warning';
+                            } else {
+                                $message_type = 'success';
+                            }
+                        } else {
+                            $message = 'Sync completed - all services are already in sync.';
+                            if (!empty($sync_results['errors'])) {
+                                $message .= ' Some issues detected: ' . implode(', ', array_slice($sync_results['errors'], 0, 2));
+                                $message_type = 'warning';
+                            } else {
+                                $message_type = 'info';
+                            }
+                        }
+                    } else {
+                        $message = 'Sync operation failed: ' . implode(', ', $sync_results['errors']);
+                        $message_type = 'danger';
+                    }
+                } catch (Exception $e) {
+                    $message = 'Sync operation failed: Operation error';
+                    $message_type = 'danger';
+                    error_log('IP sync operation exception: ' . $e->getMessage());
+                }
+                break;
         }
     }
 }
@@ -193,7 +228,43 @@ $recent_logins = $SecManager->get_all_recent_logins(10);
 // Get log monitoring data
 $log_config = $LogMonitor->get_all_config();
 $service_stats = $LogMonitor->get_service_stats();
+
+// Combine service blocked IPs and security manager blocked IPs
 $service_blocked_ips = $LogMonitor->get_unique_blocked_ips();
+$security_blocked_ips = $SecManager->get_blocked_ips();
+
+// Add security manager blocks to the service blocks array with proper formatting
+foreach ($security_blocked_ips as $security_block) {
+    // Check if this IP is already in service blocks
+    $found_in_service = false;
+    foreach ($service_blocked_ips as &$service_block) {
+        if ($service_block['ip_address'] === $security_block['ip_address']) {
+            $found_in_service = true;
+            // If security manager block is newer or indefinite, update the display
+            if ($security_block['block_time'] > $service_block['block_time'] || $security_block['unblock_time'] == 0) {
+                $service_block['reason'] = $security_block['reason'];
+                $service_block['blocking_service'] = 'security_manager';
+                $service_block['block_time'] = $security_block['block_time'];
+                $service_block['unblock_time'] = $security_block['unblock_time'];
+                $service_block['failed_attempts'] = $security_block['failed_attempts'];
+            }
+            break;
+        }
+    }
+    
+    // If not found in service blocks, add it
+    if (!$found_in_service) {
+        $service_blocked_ips[] = [
+            'ip_address' => $security_block['ip_address'],
+            'service_type' => 'security_manager',
+            'blocking_service' => 'security_manager',
+            'reason' => $security_block['reason'],
+            'block_time' => $security_block['block_time'],
+            'unblock_time' => $security_block['unblock_time'],
+            'failed_attempts' => $security_block['failed_attempts']
+        ];
+    }
+}
 
 // Get access statistics
 require_once('/docker/whp/web/libs/permission_manager.php');
@@ -649,15 +720,26 @@ if (!empty($service_blocked_ips)): ?>
         <div class="card">
             <div class="card-header d-flex justify-content-between align-items-center">
                 <h5 class="card-title mb-0">Blocked IPs</h5>
-                <form method="GET" action="" class="d-flex">
-                    <input type="hidden" name="page" value="security-management">
-                    <input type="text" class="form-control form-control-sm me-2" name="search" 
-                           placeholder="Search IP..." value="<?php echo htmlspecialchars($search); ?>" style="width: 200px;">
-                    <button type="submit" class="btn btn-sm btn-primary">Search</button>
-                    <?php if (!empty($search)): ?>
-                    <a href="?page=security-management" class="btn btn-sm btn-secondary ms-2">Clear</a>
-                    <?php endif; ?>
-                </form>
+                <div class="d-flex align-items-center gap-2">
+                    <!-- Sync Button -->
+                    <form method="POST" action="" class="d-inline">
+                        <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
+                        <input type="hidden" name="action" value="sync_blocked_ips">
+                        <button type="submit" class="btn btn-sm btn-info" title="Sync blocked IPs across all services">
+                            <i class="fa fa-sync"></i> Sync
+                        </button>
+                    </form>
+                    <!-- Search Form -->
+                    <form method="GET" action="" class="d-flex">
+                        <input type="hidden" name="page" value="security-management">
+                        <input type="text" class="form-control form-control-sm me-2" name="search" 
+                               placeholder="Search IP..." value="<?php echo htmlspecialchars($search); ?>" style="width: 200px;">
+                        <button type="submit" class="btn btn-sm btn-primary">Search</button>
+                        <?php if (!empty($search)): ?>
+                        <a href="?page=security-management" class="btn btn-sm btn-secondary ms-2">Clear</a>
+                        <?php endif; ?>
+                    </form>
+                </div>
             </div>
             <div class="card-body">
                 <div class="table-responsive">
@@ -690,7 +772,7 @@ if (!empty($service_blocked_ips)): ?>
                                     $reason = $blocked['reason'] ?? '';
                                     
                                     // Determine the block source from the reason or blocking service
-                                    if (stripos($reason, 'manual') !== false) {
+                                    if (stripos($reason, 'manual') !== false || $blocking_service == 'security_manager') {
                                         $badge_class = 'warning';
                                         $service_display = 'MANUAL';
                                     } elseif (stripos($reason, 'whp') !== false || stripos($reason, 'failed login') !== false) {
